import React, { FC } from 'react';
import { Text, View } from 'react-native';
import { Image } from 'expo-image';

import { API_HOST } from '../../../../constants';
import { styles } from './styles';
import { getFontSize } from '../../../../utils';
import { Colors } from '../../../../theme';

import TickIcon from '../../../../../assets/icons/tick.svg';
import UNIcon from '../../../../../assets/icons/un_icon.svg';
import NMIcon from '../../../../../assets/icons/nm_icon.svg';
import TBTIcon from '../../../../../assets/icons/tbt.svg';
import { getOnlineStatus } from 'src/storage';
import * as FileSystem from 'expo-file-system';
import { AvatarWithInitials } from 'src/components';

type Props = {
  avatar: string;
  first_name: string;
  last_name: string;
  date_of_birth: number;
  homebase_flag: string;
  homebase2_flag: string;
  index: number;
  score: any[];
  tbt_score?: number;
  tbt_rank?: number;
  badge_tbt?: number;
  badge_1281: number;
  badge_un: number;
  auth: number;
};

//TODO: Profile
export const Profile: FC<Props> = ({
  avatar,
  first_name,
  last_name,
  date_of_birth,
  homebase_flag,
  homebase2_flag,
  index,
  score,
  tbt_score,
  tbt_rank,
  badge_tbt,
  badge_1281,
  badge_un,
  auth
}) => {
  const scoreNames = ['NM1301', 'DARE', 'UN', 'UN+', 'TCC', 'YES', 'SLOW', 'WHS', 'KYE'];
  const isOnline = getOnlineStatus();
  const avatarBaseUri = isOnline
    ? `${API_HOST}/img/avatars/`
    : `${FileSystem.documentDirectory}avatars/`;
  const flagBaseUri = isOnline
    ? `${API_HOST}/img/flags_new/`
    : `${FileSystem.documentDirectory}flags/`;

  const TBRanking = () => {
    const colors = [
      'rgba(237, 147, 52, 1)',
      'rgba(128, 128, 128, 1)',
      'rgba(211, 211, 211, 1)',
      'rgba(187, 95, 5, 1)',
      '#808080'
    ];

    const Rank = ({ color }: { color: string }) => (
      <View style={[styles.badge, { backgroundColor: color }]}>
        {badge_tbt ? <TBTIcon /> : <Text style={{ fontSize: getFontSize(12) }}>{tbt_score}</Text>}
      </View>
    );

    return tbt_rank && tbt_rank >= 1 ? (
      <View
        style={{
          display: 'flex',
          marginTop: 10
        }}
      >
        <View style={{ display: 'flex', alignItems: 'center' }}>
          <Rank color={colors[tbt_rank - 1]} />
          <Text style={[styles.titleText, { flex: 0 }]}>TBT # {tbt_rank}</Text>
        </View>
      </View>
    ) : null;
  };

  return (
    <>
      <View style={{ alignItems: 'center', flexDirection: 'row', gap: 10, marginBottom: 5 }}>
        <View>
          <Text style={styles.rankText}>{index + 1}</Text>
        </View>
        <View>
          {avatar ? (
            <Image
              style={{ borderRadius: 24, width: 48, height: 48 }}
              source={{ uri: avatarBaseUri + avatar }}
            />
          ) : (
            <AvatarWithInitials
              text={`${first_name[0]}${last_name[0]}`}
              flag={flagBaseUri + homebase_flag}
              size={48}
            />
          )}
        </View>
        <View style={{ gap: 5, width: '75%' }}>
          <Text style={[styles.headerText, { fontSize: getFontSize(14), flex: 0 }]}>
            {first_name} {last_name}
          </Text>
          <View style={{ display: 'flex', justifyContent: 'space-between', flexDirection: 'row' }}>
            <View
              style={{
                display: 'flex',
                flexDirection: 'row',
                gap: 10,
                alignItems: 'center'
              }}
            >
              <Text
                style={{ color: Colors.DARK_BLUE, fontWeight: '600', fontSize: getFontSize(12) }}
              >
                Age: {date_of_birth}
              </Text>
              <Image source={{ uri: flagBaseUri + homebase_flag }} style={styles.countryFlag} />
              {homebase2_flag && homebase2_flag !== homebase_flag ? (
                <Image
                  source={{ uri: flagBaseUri + homebase2_flag }}
                  style={[styles.countryFlag, { marginLeft: -15 }]}
                />
              ) : null}
              <View style={{ display: 'flex', flexDirection: 'row', gap: 10 }}>
                {auth ? <TickIcon /> : null}
                {badge_un ? <UNIcon /> : null}
                {badge_1281 ? <NMIcon /> : null}
              </View>
            </View>
          </View>
        </View>
      </View>

      <View
        style={{
          display: 'flex',
          flexDirection: 'row',
          justifyContent: 'space-evenly',
          marginBottom: 15
        }}
      >
        <TBRanking />

        {score.map((number, index) => {
          if (!number) return;
          if (scoreNames[index] === 'YES' && number >= 10000) return;
          if (scoreNames[index] === 'SLOW' && number >= 4500) return;
          return (
            <View
              style={{
                display: 'flex',
                marginTop: 10
              }}
            >
              <View style={{ display: 'flex', alignItems: 'center' }}>
                <Text style={[styles.headerText, { flex: 0 }]}>{number}</Text>
                <Text style={[styles.titleText, { flex: 0 }]}>{scoreNames[index]}</Text>
              </View>
            </View>
          );
        })}
      </View>
    </>
  );
};
